Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(41)

Unified Diff: pkg/analyzer/tool/summary/idl.dart

Issue 1639533003: Record static constant public fields. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analyzer/tool/summary/idl.dart
diff --git a/pkg/analyzer/tool/summary/idl.dart b/pkg/analyzer/tool/summary/idl.dart
index 723cfc834d816048db5448a6da536f6f5cf7dcfb..61b99e81535b2642a370ded3a86cf67bb03b0332 100644
--- a/pkg/analyzer/tool/summary/idl.dart
+++ b/pkg/analyzer/tool/summary/idl.dart
@@ -296,6 +296,11 @@ enum ReferenceKind {
constructor,
/**
+ * The entity is a static const field.
+ */
+ constField,
+
+ /**
* The entity is a static method.
*/
staticMethod,
@@ -1190,10 +1195,11 @@ class UnlinkedPublicName {
int numTypeParameters;
/**
* If this [UnlinkedPublicName] is a class, the list of static methods
* and constructors. Otherwise empty.
*/
- List<UnlinkedPublicName> executables;
+ List<UnlinkedPublicName> constMembers;
}
/**
@@ -1190,10 +1195,11 @@ class UnlinkedPublicName {
int numTypeParameters;
/**
- * If this [UnlinkedPublicName] is a class, the list of static methods
- * and constructors. Otherwise empty.
+ * If this [UnlinkedPublicName] is a class, the list of members which can be
+ * referenced from constants - static constant fields, static methods, and
+ * constructors. Otherwise empty.
*/

Powered by Google App Engine
This is Rietveld 408576698